@@ -16,11 +16,7 @@ fn print_zettel_info(zettel: &[Zettel])
 {
     zettel.par_iter()
         .for_each(|z| {
-            let mut location = String::from("p");
-            if z.inbox {
-                location = String::from("i");
-            }
-            println!("[{}] {}", location, z.title);
+            println!("[{}] {}", z.project, z.title);
         })
 }
 
@@ -58,9 +54,9 @@ pub fn new(matches: &ArgMatches, cfg: &ConfigOptions) -> Result<(), Error>
     db.init()?;
 
     let title = matches.value_of("TITLE").unwrap();
-    let is_inbox = matches.is_present("inbox");
+    let project = matches.value_of("PROJECT").unwrap_or_default();
 
-    let zettel = Zettel::new(title, is_inbox);
+    let zettel = Zettel::new(title, project);
 
     let exists_in_fs = file_exists(&zettel.filename(cfg));
     let exists_in_db = db.all().unwrap().into_par_iter().any(|z| z == zettel);
@@ -90,7 +86,7 @@ pub fn update(matches: &ArgMatches, cfg: &ConfigOptions) -> Result<(), Error>
 
     let path = matches.value_of("FILENAME").unwrap();
     if file_exists(path) {
-        let zettel = Zettel::from_file(path);
+        let zettel = Zettel::from_file(cfg, path);
         db.update(cfg, &zettel)?;
     } else {
         eprintln!("error: provided path isn't a file");
